# Dear Distribution Packager. This use of require is intentional.
# Module::Install detects Build.PL usage and acts accordingly.

require 'Makefile.PL';

#      $URL$
#     $Date$
#   $Author$
# $Revision$

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
#   indent-tabs-mode: nil
#   c-indentation-style: bsd
# End:
# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
