use Test::More tests => 1;

BEGIN {
    use_ok( 'Task::Perl::Critic::IncludingOptionalDependencies' );
}

diag(
    "Testing Task::Perl::Critic $Task::Perl::Critic::IncludingOptionalDependencies::VERSION"
);

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
#   indent-tabs-mode: nil
#   c-indentation-style: bsd
# End:
# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
